#!/bin/bash

# Run-Htaccess2index-Recursively.bash
# 2/7/2021 William Craig - bill@wrcraig.com     https://wrcraig.com

# This Linux bash script will call htaccess2index.bash to run an update on index.html and index2.html in all of the subdirectories of the directory specified in htaccess-config.bash. 

# MUST BE RUN AS A NORMAL USER

#### SET ALL VARIABLES IN HTACCESS-CONFIG.BASH

#### ALSO SEE THE README FOR INFORMATION

# Run this script at the command line, or as a user's cron job ("bash <path>/Run-Htaccess2index-Recursively.bash").


########################################################
##################### Main program #####################
### If you change this you better have a backup copy ###
########################################################

set -e     # Stop on errors in subscript
export DISPLAY=:0

# Validate with user if using menu to run script, ignore if not using menu
PARENT_COMMAND=$(ps -o args= $PPID)
if [ "$PARENT_COMMAND" = "bash menu.bash" ]
then
  echo Update webpage index.html files? 
  read -p "Press enter to continue, Ctl-c to quit "
  echo 
fi

# Do it

  # Set timer to measure elapsed time for script completion
  starttime=$(date '+%s%N')

  # Assuming that all the scripts are in the same directory,
  # Find and change to the scripts directory to access the config file
  MY_PATH="`dirname \"$0\"`"              # relative
  MY_PATH="`( cd \"$MY_PATH\" && pwd )`"  # absolutized and normalized
  
  if [ -z "$MY_PATH" ] ; then
    highlight "For some reason, the path to the scripts is not accessible"
    
    # Send error message directly to browser because Logfile is not defined yet
    echo dir= ${PWD}
    echo '<p></p><center><font style="background-color: #00FF00"> ERROR FOUND - Webmaster, check Logfile, the path to the scripts is not accessible to the script. </font></center><p></p>' >> errorfile.html
    xdg-open errorfile.html
    sleep 1
    printf .
    sleep 1
    printf .
    sleep 1
    printf .
    sleep 1
    printf .
    echo
    rm errorfile.html
    exit 1
  fi

scriptpath="$MY_PATH"

cd $scriptpath

# Ensure necessary files are present
if [ -f htaccess-config.bash ] || [ ! -f htaccess2index.bash ] || [ ! -f functions.bash ]
then
# Import functions and variables from the config and functions files
source $scriptpath"/htaccess-config.bash"
source $scriptpath"/functions.bash"
else
  highlight "Cannot find necessary bash scripts. All bash scripts should be in the same directory."
  
      # Send error message directly to browser because Logfile is not defined yet
    echo '<p></p><center><font style="background-color: #00FF00"> ERROR FOUND - Webmaster, cannot find necessary bash scripts. All bash scripts should be in the same directory. </font></center><p></p>' >> errorfile.html
    xdg-open errorfile.html
    sleep 1
    printf .
    sleep 1
    printf .
    sleep 1
    printf .
    sleep 1
    printf .
    echo
    rm errorfile.html
    exit 1
fi

# ID the subscript to run recursively
subscript=htaccess2index.bash

# Run some functions and validate files
TestFiles
startingsubscript
checkflagdir
locateNDlog

# Check if the config file found "mediainfo" to find duration of media files
if [ "${mediainf}" = "f" ]
then
  echo '<br><font style="background-color: #00FF00">>></font> '$package' package not found, cannot determine duration of any A/V files</font>' >>  $Logfile
fi

###### Looks ok, begin processing

cd $BaseDirectory




# Function to choose whether to run subscript in the base directory or to run recursively at all. Then Execute recursive_for_loop and/or RunInBaseDir

  choice





######## Post Results of processing
if [ -f $flagdir/.flagerrorfile ] || [ -f $flagdir/.NDflagfile ]
then
  echo
  highlight " ====== ERRORS  FOUND ======= "
#  echo '<br><b> ====== ERRORS  FOUND ======= </b>' >> $Logfile
  if [ -f $errorsound ]
  then
     echo aplay -q $errorsound  && play -q $errorsound -t alsa
  fi

  if [ -f $flagdir/.flagerrorfile ]
  then
      highlight "Check" $Logfile
    fi

  if [ -f $flagdir/.flagerrorfile ] && [ -f $flagdir/.NDflagfile ]
  then
      highlight "      and      "
fi

  if [ -f $flagdir/.NDflagfile ]
  then
      highlight "Check" $NoDescription
      echo '<br><b><font color="DarkRed">Check' $NoDescription '</font></b>' >> $Logfile
  else
      echo $(date +%y-%m-%d/%I%p)"  All files have descriptions" >> $NoDescription
  fi
 fi

# After all recursions, remove hidden files used to carry the value of variables through the recursions of the called file.

if [ -f $flagdir/.flagerrorfile ]
then
    rm ${flagdir}/.flagerrorfile
fi

if [ -f $flagdir/.NDflagfile ]
then
    rm ${flagdir}/.NDflagfile
fi

# Trim size of NoDescription list
# Find # lines in NoDescription
if [ -f $NoDescription ]
then
  lines=$(wc -l $NoDescription | cut -f1 -d' ')
  # Delete extra lines from the beginning of NoDescription
  if [ $lines -gt $NDmaxfiles ]
  then
    max=$(($lines-$NDmaxfiles))
    filler=1,${max}d
    sed -i "$filler" "$NoDescription"
  fi
fi

trimlogfile

echo
echo "==== Finished With All Subdirectories ===="
echo "========== Recursion Complete ============"
echo "<br>"$(date +%y-%m-%d/%H:%M:%S) "Index files rebuild is complete." >> $Logfile

ReportTime





