#!/bin/bash

# UpdateOwnerAndPermissions.bash
# 10/22/2020 William Craig - bill@wrcraig.com  https://wrcraig.com

# This Linux bash script will correct file ownership and permissions that may be wrong when new files are added to a website.

# MUST BE RUN AS ROOT
#  (usually called by UpdateOwnerAndPermissionsRecursively.bash so that all subdirectories are checked)

#### SET ALL VARIABLES IN HTACCESS-CONFIG.BASH
#### ALSO SEE THE README FOR INFORMATION





##################### Main Script ######################
### If you change this you better have a backup copy ###
########################################################

# Assuming that all the scripts are in the same directory,
# change to the scripts directory to access the config file
MY_PATH="`dirname \"$0\"`"              # relative
MY_PATH="`( cd \"$MY_PATH\" && pwd )`"  # absolutized and normalized
if [ -z "$MY_PATH" ] ; then
  echo "for some reason, the path is not accessible to the script (e.g. permissions re-evaled after suid)"
  exit 1  # fail
fi
scriptpath="$MY_PATH"

# Import functions and variables from the config  and functions files
source $scriptpath"/htaccess-config.bash"
source $scriptpath"/functions.bash"

# Enforce run as root
if [[ $EUID -ne 0 ]]; then
  echo "<br>You must run this script as Root." >> $Logfile
  highlight "Cannot run as a normal user. You must be Root"
  echo
  exit 1
fi

###### Looks ok, begin processing

# See if files are valid
TestFiles;

# Validate settings for permissions
a=$(echo $File_permissions | cut -c1-1)
b=$(echo $File_permissions | cut -c2-2)
c=$(echo $File_permissions | cut -c3-3)
d=$(echo $Dir_permissions | cut -c1-1)
e=$(echo $Dir_permissions | cut -c2-2)
g=$(echo $Dir_permissions | cut -c3-3)

if [ ${#File_permissions} -gt 3 ] || [ ${#Dir_permissions} -gt 3 ] || [ ${#File_permissions} -lt 3 ] || [ ${#Dir_permissions} -lt 3 ] || [ $a -gt 7 ] || [ $a -lt 0 ] || [ $b -gt 7 ] || [ $b -lt 0 ] || [ $c -gt 7 ] || [ $c -lt 0 ] || [ $d -gt 7 ] || [ $d -lt 0 ] || [ $e -gt 7 ] || [ $e -lt 0 ] || [ $g -gt 7 ] || [ $g -lt 0 ]
then
highlight "Permissions must contain three numbers, each from 0 thru 7."
echo "<br>"$(date +%y-%m-%d/%H:%M:%S) "Permissions must contain three numbers, each from 0 thru 7." >> $Logfile
exit 1
fi

# Set array constants for permission triplet translation"
triplets=( rwx rw- r-x r-- -wx -w- --x --- )
numeric=( 7 6 5 4 3 2 1 0 )

# find permission triplets for requested FILE permissions
fi=0
while (( fi++ < ${#File_permissions} ))
do
char=$(expr substr "$File_permissions" $fi 1)

for (( fj=0; fj <= ${#numeric[@]}; fj++ ))
  do
  if [[ ${numeric[$fj]} == $char ]]
  then
    if [ $fi -eq 1 ]
    then
      ft=${triplets[$fj]}
      tripf1=$ft
    fi

    if [ $fi -eq 2 ]
    then
      ft=${triplets[$fj]}
      tripf2=$ft
    fi

    if [ $fi -eq 3 ]
    then
      ft=${triplets[$fj]}
      tripf3=$ft
    fi
  fi
  done
done

filenewtriple=$tripf1$tripf2$tripf3


# find permission triplets for requested DIRECTORY permissions
di=0
while (( di++ < ${#Dir_permissions} ))
do
char=$(expr substr "$Dir_permissions" $di 1)
for (( dj=0; dj <= ${#numeric[@]}; dj++ ))
  do
  if [[ ${numeric[$dj]} == $char ]]
  then
    if [ $di -eq 1 ]
    then
      dt=${triplets[$dj]}
      tripd1=$dt
    fi

    if [ $di -eq 2 ]
    then
      dt=${triplets[$dj]}
      tripd2=$dt
    fi

    if [ $di -eq 3 ]
    then
      dt=${triplets[$dj]}
      tripd3=$dt
   fi
  fi
  done
done

dirnewtriple=$tripd1$tripd2$tripd3


# For All SpecialPermission files
# Find the new triplets

sp_no=0
while (( sp_no++ < 5 ))
do
# need to find the value of a variable's variable, can't have a $ on the left side of an assignment
 # So need to store the variable name in a variable first
      specialfilepermissionsxm=specialfilepermissions$sp_no
      specialfilexm=specialfile$sp_no
# The ! (and braces) trigger  indirect variable expansion
      specialfilepermissionsx="${!specialfilepermissionsxm}"
      specialfilex="${!specialfilexm}"

# check for unbalanced special file permissions
if [ ! -z $specialfilepermissionsx ] && [ -z $specialfilex ]
then
  highlight User variables \"specialfile$sp_no\" and \"specialfilepermissions$sp_no\" must both be filled or blank.
  echo "<br>"$(date +%y-%m-%d/%H:%M:%S) "User variables \"specialfile$sp_no\" "and \"specialfilepermissions$sp_no\" "must both be filled or blank." >> $Logfile
  exit 1
fi

if [ -z $specialfilepermissionsx ] && [ ! -z $specialfilex ]
then
  highlight User variables \"specialfile$sp_no\" and specialfilepermissions$sp_no must both be filled or blank
  echo "<br>"$(date +%y-%m-%d/%H:%M:%S) "User variables \"specialfile$sp_no\" "and \"specialfilepermissions$sp_no\" "must both be filled or blank." >> $Logfile
  exit 1
fi

if [ -z $specialfilepermissionsx ]
then
# echo Blank entry, skipping specialfilepermissions$sp_no
continue 3
fi

# Validate settings for special permissions
spc1=$(echo $specialfilepermissionsx | cut -c1-1)
spc2=$(echo $specialfilepermissionsx | cut -c2-2)
spc3=$(echo $specialfilepermissionsx | cut -c3-3)

#check validity of all requested special permissions
if [[ ${#specialfilepermissionsx} -gt 3 ]] || [[ ${#specialfilepermissionsx} -lt 0 ]] || [[ $spc1 -gt 7 ]] || [[ $spc1 -lt 0 ]] || [[ $spc2 -gt 7 ]] || [[ $spc2 -lt 0 ]] || [[ $spc3 -gt 7 ]] || [[ $spc3 -lt 0 ]]
then
highlight "SpecialPermissions must contain three numbers, each from 0 thru 7."
echo "<br>"$(date +%y-%m-%d/%H:%M:%S) "SpecialPermissions must contain three numbers, each from 0 thru 7." >> $Logfile
exit 1
fi

# find permission numeric for requested special permissions.
# use one charx in turnVisit MovieParadise.org
i=0
while (( i++ < 3 ))
do
charx="$(( spc$i ))"

# find match fron the numeric array
for (( j=0; j < ${#numeric[@]}; j++ ))
  do
  if [[ ${numeric[$j]} = $charx ]]
  then
# Save the corresponding value from the triplets array
    if [ $i -eq 1 ]
    then
      t=${triplets[$j]}
      trip1=$t
    elif [ $i -eq 2 ]
    then
      t=${triplets[$j]}
      trip2=$t
    elif [ $i -eq 3 ]
    then
      t=${triplets[$j]}
      trip3=$t
   fi
fi

ftriple=$trip1$trip2$trip3

if [ $sp_no == 1 ]
then
  newtriple_specialpermission1=$ftriple
elif [ $sp_no == 2 ]
then
  newtriple_specialpermission2=$ftriple
elif [ $sp_no == 3 ]
then
  newtriple_specialpermission3=$ftriple
elif [ $sp_no == 4 ]
then
  newtriple_specialpermission4=$ftriple
elif [ $sp_no == 5 ]
then
  newtriple_specialpermission5=$ftriple
fi

done
done
done


# Loop through all files in the current directory
for file in *
do
  echo Checking $file
  currentdir=${PWD}"/"

# Check for spaces in filename
if [[ "$file" == *" "* ]]
then
highlight "Spaces found in filename. Skipping" $currentdir$file". Please fix manually or use the script ReplSpacesinSubdirs.Filenames.bash to fix."
echo "<br>"$(date +%y-%m-%d/%H:%M:%S) "Spaces found in filename. Skipping" $currentdir$file". Please fix manually or use the script ReplSpacesinSubdirs.Filenames.bash to fix." >> $Logfile
continue
#exit 1
fi

# Identify old permissions for the file
listall=$(ls -dl $file)
oldtriple=$(echo $listall | cut -c2-10)
oldtriplecut=$(echo $listall | cut -c2-9)
oldtripleend=$(echo $listall | cut -c10-10)

# Identify new permissions for the file
dirnewtriplecut=$(echo $dirnewtriple | cut -c1-8)
dirnewtripleend=$(echo $dirnewtriple | cut -c9-9)

# Reduce setguid to one char
  setguid=$(echo $setguid | cut -c1-1)

# Reduce sticky bit to one char
stickybit=$(echo $stickybit | cut -c1-1)

if [[ $stickybit = y ]] || [[ $stickybit = Y ]]
then
  stickybit1=1
  dirnewtripleend=t
else
  stickybit1=""
fi


############## change permissions if directory
if [ -d $file ] && [[ $oldtriple != $dirnewtriplecut$dirnewtripleend ]]
then
  echo "Changing directory permissions from" $oldtriple "to" $dirnewtriplecut$dirnewtripleend "("$stickybit1$Dir_permissions") for" $file
  chmod --preserve-root $stickybit1$Dir_permissions $file 
fi

# Set the stickybit and guid as specified
if [ -d $file ]
then
  if [[ $stickybit = y ]] || [[ $stickybit = Y ]]
  then
    echo Setting stickybit
    chmod --preserve-root o+t $file
  fi

  if [[ $stickybit = r ]] || [[ $stickybit = R ]]
  then
    echo Removing stickybit
    chmod --preserve-root o-t $file
  fi

  if [[ $setguid = y ]] || [[ $setguid = Y ]]
  then
    echo "Setting guid for" $file
  chmod --preserve-root a-s $file
  chmod --preserve-root g+s $file
  fi

  if [[ $setguid = r ]] || [[ $setguid = R ]]
  then
    echo "Removing guid for" $file
  chmod --preserve-root a-s $file     
  fi
fi


############## change permissions if regular file
if [ -f $file ] && [[ $oldtriple != $filenewtriple ]]
then
  echo "Changing file permissions from" $oldtriple "to" $filenewtriple "("$File_permissions") for" $file
  chmod --preserve-root $File_permissions $file     
fi

# Change owner/group
if [[ $listall != *" $owner $group "* ]]
then
  echo "Changing owner/group for "$file
  chown --preserve-root $owner":"$group $file      
fi

done 

############# change permissions for special permissions
# loop thru spfilenames
sp_no=0
while (( sp_no++ < 5 ))
do
 # need to find the value of a variable's variable
 # can't have a $ on the left side of an assignment
      specialfilexm=specialfile$sp_no    # Need to store the variable name in a variable first
      newtriple_specialpermissionxm=newtriple_specialpermission$sp_no
      specialfilepermissionsxm=specialfilepermissions$sp_no
 # The ! (and braces) trigger  indirect variable expansion
      specialfilex="${!specialfilexm}"
      newtriple_specialpermissionx="${!newtriple_specialpermissionxm}"
      specialfilepermissionsx="${!specialfilepermissionsxm}"
 #     specialfilex=$PathToFiles/$specialfilex

      if [ -z $specialfilex ]
      then
       # echo Blank entry, skipping $specialfilex
        continue
      else
        echo Checking special file $specialfilex
# Identify old permissions for the file
listalls=$(ls -dl $specialfilex)
oldtriples=$(echo $listalls | cut -c2-10)
oldtriplecuts=$(echo $listalls | cut -c2-9)
oldtripleends=$(echo $listalls | cut -c10-10)

      fi

        # Check for invalid filename
      if [ ! -e $specialfilex ] # && [ ! -d $specialfilex ]
      then
        highlight "Specialfile does not exist:" $specialfilex
        echo "<br>"$(date +%y-%m-%d/%H:%M:%S) "Specialfile does not exist:" $specialfilex"." >> $Logfile
        continue 2
      fi

d=$(echo $newtriple_specialpermissionx |cut -c1-3)
e=$(echo $newtriple_specialpermissionx |cut -c4-6)
z=$(echo $newtriple_specialpermissionx |cut -c7-9)

if [ $oldtriples != $newtriple_specialpermissionx ]
then
if [[ " ${triplets[*]} " == *" $d "* ]]
then
  if [[ " ${triplets[*]} " == *" $e "* ]]
  then
    if [[ " ${triplets[*]} " == *" $z "* ]]
    then
      echo Updating special permissions for $specialfilex from $oldtriples to $newtriple_specialpermissionx "("$specialfilepermissionsx")"

     chmod --preserve-root $specialfilepermissionsx $specialfilex
    fi
  fi
fi
fi
done

echo Completed directory: ${PWD}


