#!/bin/bash

# UpdateOwnerAndPermissionsRecursively.bash
# 10/22/2020 William Craig - bill@wrcraig.com     https://wrcraig.com

# This Linux bash script will call UpdateOwnerAndPermissions.bash to run an update on owners and permissions in all of the subdirectories of directory specified in htaccess-config.bash. 

# MUST BE RUN AS ROOT (usually as a cron job)

#### SET ALL VARIABLES IN HTACCESS-CONFIG.BASH
#### ALSO SEE THE README FOR INFORMATION

# Run this script at the command line, or as a root cron job ("bash <path>/RunFileRecursively.bash").



########################################################
##################### Main program #####################
### If you change this you better have a backup copy ###
########################################################

set -e     # Stop on errors in subscript

# Validate with user if using menu to run script, ignore if not using menu
PARENT_COMMAND=$(ps -o args= $PPID)
if [ "$PARENT_COMMAND" = "sudo bash UpdateOwnerAndPermissionsRecursively.bash" ]
then
  echo Update owner and permissions of files and directories? 
  read -p "Press enter to continue, Ctl-c to quit "
  echo 
fi
# Do it


# Set timer to measure elapsed time for script completion
starttime=$(date '+%s%N')

# Assuming that all the scripts are in the same directory,
# change to the scripts directory to access the config file
MY_PATH="`dirname \"$0\"`"              # relative
MY_PATH="`( cd \"$MY_PATH\" && pwd )`"  # absolutized and normalized
if [ -z "$MY_PATH" ] ; then
  echo "for some reason, the path is not accessible to the script (e.g. permissions re-evaled after suid)"
  exit 1  # fail
fi
scriptpath="$MY_PATH"


cd $scriptpath

# ID the subscript to run recursively
subscript=UpdateOwnerAndPermissions.bash

# Ensure necessary files are present
if [ -f htaccess-config.bash ] || [ ! -f htaccess2index.bash ] || [ ! -f functions.bash ]
then
  # Import functions and variables from the config and functions files
  source $scriptpath"/htaccess-config.bash"
  source $scriptpath"/functions.bash"
else
  echo "Cannot find necessary bash scripts. All bash scripts should be in the same directory."
  echo "<br>Cannot find necessary bash scripts. All bash scripts should be in the same directory." >> $Logfile
  exit 1
fi

# Import functions and variables from the config file
source $scriptpath"/htaccess-config.bash"

# Run some functions and validate files
TestFiles
startingsubscript
checkflagdir

###### Looks ok, begin processing

cd $BaseDirectory

# Enforce run as root
if [ $(id -u) != 0 ]; then
  echo "<br>""You must run this script as Root.<hr>" >> $Logfile
  highlight "Cannot be run as a normal user. You must be Root"
  echo
  exit 1
fi

# Enforce not run in root directory
if [ ${PWD} = / ]
  then
    echo You should not run this script on the root directory!!!!!
    echo "<br>""You should not run this script on the root directory!!!!!<hr>" >> $Logfile
    echo
    exit 1
fi



##### Execute recursive_for_loop and/or RunInBaseDir
choice


echo
# Execute commands for individual files and directories as specified in the config file
if [ ! -z "$a" ]
then
 echo "Executing non-recursive command a: \""$a\"
 echo "<br>--------"$(date +%y-%m-%d/%H:%M:%S)"." "Executing non-recursive command a: \""$a\" >> $Logfile
cmda=($a)
"${cmda[@]}"
fi

if [ ! -z "$b" ]
then
 echo "Executing non-recursive command b: \""$b\"
 echo "<br>--------"$(date +%y-%m-%d/%H:%M:%S)"." "Executing non-recursive command b: \""$b\" >> $Logfile
cmdb=($b)
"${cmdb[@]}"
fi

if [ ! -z "$c" ]
then
 echo "Executing non-recursive command c: \""$c\"
 echo "<br>--------"$(date +%y-%m-%d/%H:%M:%S)"." "Executing non-recursive command c: \""$c\" >> $Logfile
cmdc=($c)
"${cmdc[@]}"
fi

if [ ! -z "$d" ]
then
 echo "Executing non-recursive command d: \""$d\"
 echo "<br>--------"$(date +%y-%m-%d/%H:%M:%S)"." "Executing non-recursive command d: \""$d\" >> $Logfile
cmdd=($d)
"${cmdd[@]}"
fi

if [ ! -z "$e" ]
then
 echo "Executing non-recursive command e: \""$e\"
 echo "<br>--------"$(date +%y-%m-%d/%H:%M:%S)"." "Executing non-recursive command e: \""$e\" >> $Logfile
cmde=($e)
"${cmde[@]}"
fi

if [ ! -z "$f" ]
then
 echo "Executing non-recursive command c: \""$f\"
 echo "<br>--------"$(date +%y-%m-%d/%H:%M:%S)"." "Executing non-recursive command c: \""$f\" >> $Logfile
cmdf=($f)
"${cmdf[@]}"
fi

if [ ! -z "$g" ]
then
 echo "Executing non-recursive command d: \""$g\"
 echo "<br>--------"$(date +%y-%m-%d/%H:%M:%S)"." "Executing non-recursive command d: \""$g\" >> $Logfile
cmdg=($g)
"${cmdg[@]}"
fi

if [ ! -z "$h" ]
then
 echo "Executing non-recursive command e: \""$h\"
 echo "<br>--------"$(date +%y-%m-%d/%H:%M:%S)"." "Executing non-recursive command e: \""$h\" >> $Logfile
cmdh=($h)
"${cmdh[@]}"
fi

if [ ! -z "$a" ] || [ ! -z "$b" ] || [ ! -z "$c" ] || [ ! -z "$d" ] || [ ! -z "$e" ] || [ ! -z "$f" ] || [ ! -z "$g" ] || [ ! -z "$h" ]
then
  echo $(date +%y-%m-%d/%H:%M:%S) "Completed special commands non-recursively:"
  echo "<br>--------"$(date +%y-%m-%d/%H:%M:%S) "Completed special commands non-recursively. " >> $Logfile
fi

trimlogfile
ReportTime

