#!/bin/bash

# These are the functions used for the htaccess2index scripts


# PATH TO THE SUBSCRIPTS TO BE RUN (Keep all of the scripts in the same directory)
scriptpath=${PWD}"/"


# Import variables from the config file
#source $scriptpath"/htaccess-config.bash"



#  Get the number of packages installed that match the package
    package=mediainfo
    
    num=$(dpkg -l "$package" 2>/dev/null | egrep '^ii' | wc -l)

    if [ $num -eq 1 ]; then
        # installed
        mediainf="t"
    elif [ $num -gt 1 ]; then
        echo there is more than one package matching $package
    else
        mediainf="f"
    fi




function choice   {
# Function to choose whether to run recursively
# Reduce StopRecursive to one character
StopRecursive=$(echo $StopRecursive | cut -c1-1)
# Make it lower case
StopRecursive=${StopRecursive,}
if [ -z "$StopRecursive" ] || ([ $StopRecursive != y ] && [ $StopRecursive != n ])
then
  highlight " StopRecursive must be y or n "
  echo "<br><b><font color="DarkRed">StopRecursive must be y or n</font></b>" >> $Logfile
  exit 1
fi

#if [ $RunInBaseDirectory = y ]
#then
  RunInBaseDir
#fi

if [ $StopRecursive = n ]
then
  echo "Running Recursions"
  recursive_for_loop
fi
           }





function recursive_for_loop   {
# This is a Function to Recurse a script an infinite number of levels below the Current Directory, which will not be included (see variable #9) 
  for entry in *     # Iterate through the current directory
    do
      if [ -d "$entry" ]  # If the entry is a directory
      then
        cd $entry         # Change to that directory
	    echo
        highlight "Scanning directory:" $entry
        bash $scriptpath$subscript      # run the subscript in that directory
        recursive_for_loop;  # Go to the next iteration
      else                # if the entry is not a directory
        continue         # Go to the next iteration
      fi
      # When we run out of subdirectories in this branch, go up a level for next "f"
      cd ..
    done        
    # No more subdirectories, we have reached the end of the branches, recursions function done
	}






function checkflagdir {
# Check if we can write temp files to the user's home directory to use hidden files to carry variables through the recursions (hidden files are created by htaccess2index.bash to track errors).
flagdir=$HOME
touch ${flagdir}/testfile.log > /dev/null 2>&1
if [ -f ${flagdir}/testfile.log ]
then
   chmod --preserve-root 666 ${flagdir}/testfile.log
   rm ${flagdir}/testfile.log
else
   highlight "Cannot write to" $flagdir". Unable to carryover variables through recursions. "
   echo "<br><b><font color="DarkRed">Cannot write to" $flagdir". Unable to carryover variables through recursions.</font></b>" >> $Logfile
   exit 1
fi
     }




function locateNDlog {
  # Find the path to the logfile 
  temp=$Logfile
  pathtologfile=${temp%/*}        # everything before the last slash
  # define NoDescription.log in the same directory
  NoDescription=$pathtologfile"/NoDescription.log"
       }





function highlight {
# Set "highlight" to act the same as "echo", but with colored and hi-lighted text
if [[ -t 2 ]]
  then
  echo $'\033[31;2;47m'"$@"$'\033[0m'
else
  echo "$@" ; fi >&2
     }





function TestFiles {
# Function to see if files are valid
touch $Logfile > /dev/null 2>&1 || highlight "   Logfile Path & Filename is not valid/accessible   "
if [ ! -f $Logfile ]
then
  exit 1
fi

if [ ! -d $BaseDirectory ]
then
  echo  "<br><b><font color="DarkRed">BaseDirectory-" $BaseDirectory "-is not valid</font></b>" >> $Logfile
  highlight "BaseDirectory-" $BaseDirectory "-is not valid"
  if [ -f $errorsound ]
  then
     echo aplay -q $errorsound && play -q $errorsound -t alsa
  fi
exit 1
fi
     }






function enter_user {
echo
if [ -z "${password_location}" ]
    then
    echo Please enter the location for the file containing id\'s and passwords in the config file
    read -p "Press enter to continue."
    bash menu.bash
fi
dirfile=${password_location}/.htpasswd
if [ ! -f $dirfile ]
    then
    touch $dirfile
fi

read -p "Enter the userid to be added, - Ctl-c to quit: " id

# if user already there then ask if delete and reenter
isthere=$(grep -c $id $dirfile)

if [ "$isthere" -gt "0" ]
then
    echo
    echo User $id already has an account.
    read -p "Do you want to delete and reenter as a new user (y/n)? - Ctl-c to quit: " answer
    if [ "$answer" = "y" ] || [ "$answer" = "Y" ]
    then
        # delete user id
        htpasswd -D $dirfile $id
        echo
    else
        echo
        bash menu.bash
    fi
fi

echo
echo Adding user id $id
htpasswd -m $dirfile $id
echo
     }






function delete_user {
if [ -z "${password_location}" ]
    then
    echo Please enter the location for the file containing id\'s and passwords in the config file
    read -p "Press enter to continue."
    bash menu.bash
fi

dirfile=${password_location}/.htpasswd
if [ ! -f $dirfile ]
    then
    echo
    echo Cannot find id file $dirfile
    echo
    read -p "Press enter to continue."
    bash menu.bash
fi

echo
read -p "Enter the userid to be deleted, - Ctl-c to quit: " id

# if user already there then ask if delete and reenter
isthere=$(grep -c $id $dirfile)
if [ "$isthere" -gt "0" ]
then
    echo
    echo Userid $id has an account.
    read -p "Do you want to delete the account (y/n)? - Ctl-c to quit: " answer
    if [ "$answer" = "y" ] || [ "$answer" = "Y" ]
    then
        # delete user id
        htpasswd -D $dirfile $id
    fi
else
    echo
    echo There is no account matching $id
fi
     }






function startingsubscript {
# Notify that we are starting the subscript
echo 
if [ $StopRecursive = n ]
then
  recursive=recursively
fi
  highlight $(date +%y-%m-%d/%H:%M) "Running" $subscript $recursive
  echo "<hr><b>" $(date +%y-%m-%d/%H:%M:%S) "<font color="blue"> Running" $subscript $recursive"</font></b>" >> $Logfile
echo
     }





function RunInBaseDir {

# Function to choose whether to run subscript in the base directory

# Reduce UpdateOwnerAndPermissionsBase to one character
UpdateOwnerAndPermissionsBase=$(echo $UpdateOwnerAndPermissionsBase | cut -c1-1)

# Make it lower case
UpdateOwnerAndPermissionsBase=${UpdateOwnerAndPermissionsBase,}

if [ -z "$UpdateOwnerAndPermissionsBase" ] || ([ $UpdateOwnerAndPermissionsBase != y ] && [ $UpdateOwnerAndPermissionsBase != n ])
then
  highlight UpdateOwnerAndPermissionsBase must be y or n
  echo "<br><b><font color="DarkRed">UpdateOwnerAndPermissionsBase must be y or n</font></b>" >> $Logfile
  exit 1
fi

# Reduce htaccess2indexBase to one character
htaccess2indexBase=$(echo $htaccess2indexBase | cut -c1-1)

# Make it lower case
htaccess2indexBase=${htaccess2indexBase,}

if [ -z "$htaccess2indexBase" ] || ([ $htaccess2indexBase != y ] && [ $htaccess2indexBase != n ])
then
  highlight htaccess2indexBase must be y or n
  echo "<br><b><font color="DarkRed">htaccess2indexBase must be y or n</font></b>" >> $Logfile
  exit 1
fi

highlight Scanning base directory: $BaseDirectory

if [ "$UpdateOwnerAndPermissionsBase" = "y" ] && [ "$subscript" = "UpdateOwnerAndPermissions.bash" ]
then
  RunInBaseDirectory=y
  echo "<br>Running in specified base directory:" $BaseDirectory  >> $Logfile
  cd $BaseDirectory
  bash $scriptpath/$subscript
else 
  RunInBaseDirectory=n
fi

if [ "$htaccess2indexBase" = "y" ] && [ "$subscript" = "htaccess2index.bash" ]
then
  RunInBaseDirectory=y
  echo "<br>Running in specified base directory:" $BaseDirectory  >> $Logfile
  cd $BaseDirectory
  bash $scriptpath/$subscript
else 
  RunInBaseDirectory=n
fi

if [ $RunInBaseDirectory = n ] && [ $StopRecursive = y ]
then
  highlight ' Nothing to do! ("StopRecursive"=y and "RunInBaseDirectory"=n) '
  echo
  echo '<br><b><font color="DarkRed">Nothing to do!</b> ("StopRecursive"=y and "RunInBaseDirectory"=n)</font>' >> $Logfile
  exit 1
fi
         }









#########################################################
#    Build an html file sorted by filename of video     #
#          and another by year and rating               #
#########################################################

function Makehtml {

echo
highlight "Generating" ${pout##*/}", for" $kind "in order by" $type"."
echo

    # Start new Output File

    # Hard code the reserved lines in the header because they are complex and use new variables
o="<font style='color: DarkRed'>Ordered by"
p="</font>"
fst="<a href=\""
trd="</a></b>"
snd="\">Get listing by "

header5="<title>${dir}</title>"
header11="<center><b><font size=+3>${dir}</font></center>"
header12="<center>$o ${type} $p</center>"
header15="<p></p><center>${fst}${pout1}${snd}${type1}${trd}</center>"
header16='<center><b><a href="..">Go BACK</a></b></center>'

# Write header info to output file
echo $header1 > $out   # The single > truncates any existing file then appends to it.
echo $header2 >> $out  # the double >> appends to the file
echo $header3 >> $out
echo $header4 >> $out
echo $header5 >> $out
echo $header6 >> $out
echo $header7 >> $out
echo $header8 >> $out
echo $header9 >> $out
echo $header10 >> $out
echo $header11 >> $out
echo $header12 >> $out
echo $header13 >> $out
echo $header14 >> $out
echo $header15 >> $out
echo $header16 >> $out
echo $header17 >> $out

# ensure we can all read and write the file
chmod --preserve-root 766 $out

# Creating a "reconstruction" placeholder index file "pout" displayed while updating the indexes. ######
echo $header1 > $pout    # The single > truncates any existing file then appends to it.
echo $header2 >> $pout   # the double >> appends to the file
echo $header3 >> $pout
echo $header4 >> $pout
echo $header5 >> $pout
echo $header6 >> $pout
echo $header7 >> $pout
echo $header8 >> $pout
echo $header9 >> $pout
echo $header10 >> $pout
echo >> $pout
echo >> $pout
header555="<center><font style='color: red' size=+2><p></p><br/>Reconstructing index, please reload this page in a minute or two.</font></center>"
echo $header555 >> $pout
echo >> $pout
echo >> $pout
echo $footer1 >> $pout
echo $footer2 >> $pout
echo $footer3 >> $pout
echo $footer4 >> $pout
echo $footer5 >> $pout
echo $footer6 >> $pout

# ensure we can all read and write the file
chmod --preserve-root 766 $pout
     }





function ReportTime {
echo $subscript completed
# Calculate time elapsed to run the script
endtime=$(date '+%s%N')
secs=$(( $endtime / 1000000000 - $starttime / 1000000000 ))
printf "Elapsed Time: "
printf '%dh:%dm:%ds\n' $(($secs/3600)) $(($secs%3600/60)) $(($secs%60))  # must be separate line
printf "<b>Elapsed Time:</b> " >> $Logfile
printf '%dh:%dm:%ds\n' $(($secs/3600)) $(($secs%3600/60)) $(($secs%60)) >> $Logfile  # must be separate line
     }





function trimlogfile {
# Find # lines in Logfile
if [ -f $Logfile ]
then
  lines=$(wc -l $Logfile | cut -f1 -d' ')
  # Delete extra lines in Logfile
  if [ $lines -gt $logmaxfiles ]
  then
    max=$(($lines-$logmaxfiles))
    filler=1,${max}d
    sed -i "$filler" "$Logfile"
  fi
fi
     }




####### End of functions #######

