#!/bin/bash

# This is the config file for variables used in the following bash scripts: 

  # To be run as normal user:
     # menu.bash 
     # ReplSpacesinSubdirsFilenames.bash (Replaces spaces in filenames with a dot)
     # Add=ToDirectoryNames.sh (Adds an equal sign to directory names to avoid conflict w/file names)
     # htaccess2index.bash
     # Run-Htaccess2index-Recursively.bash (Can be run as a user cron job)
  # To be run as Root
     # UpdateOwnerAndPermissions.bash
     # UpdateOwnerAndPermissionsRecursively.bash (Can be run as a root cron job)

  # To make your life easier:
     # enterdescriptions.xlsx  (Spreadsheet to aid in data entry)
     # Sample.of.index.html.output.png




#########################################################################
# Enter user preferences for variable in ReplSpacesinSubdirs.Files.bash
#########################################################################
# This will recurse through every subdirectory,

# 1. What is the highest directory below which you want to replace all spaces with a dot?

     RemoveSpaces=/var/www





#########################################################################
# Enter user preferences for variable in Add-eqsign-ToDirectoryNames.bash
#########################################################################
# This will recurse through every subdirectory,
# Fails if there are any spaces in directory names. 

# 2. What is the highest directory below which you want to append equals signs?
#   (You will be offered a choice of either 1 or 2 levels below your entry)  

      AppendEqSignDir=/var/www/html





#########################################################################
# Enter user preference for location of an ID and password file
#########################################################################
# 3. If you want to restrict access to a directory enter a path to the 
#    hidden file which will contain authorized user id's with encrypted passwords:

     password_location=/home/bill

# Recommend you keep this path OUT of the web root for better security.

# MAKE SURE # the following 4 lines are added to the top of the .htaccess file
# in any directories that you want to be restricted (without the #):

# AuthType Basic
# AuthName "Restricted Area"
# AuthUserFile <your password_location named above>/.htpasswd
# Require valid-user




########################################################################
# Enter user preferences for variables common to all the other scripts
########################################################################

# 4. DEFINE THE FULL PATH AND FILENAME FOR AN HTML FORMATTED ERROR LOG (You will need write access to that directory, the filename should end in ".html".
     # Example: Logfile=/home/logs/errorlog.html

     Logfile=/var/www/html/errorlog.html

# 5. DEFINE THE MAXIMUM NUMBER OF ERRORS TO LIST IN YOUR Logfile.
     # Example: logmaxfiles=200

     logmaxfiles=200

# 6. Specify a BASEDIRECTORY, the first directory ABOVE the those containing the files to be updated recursively for indexes or to change owner and permissions. Recommend that the scripts are not in or under the basedirectory.

	 BaseDirectory=/var/www/html

# 7. Do you want to run the scripts IN THE BASE DIRECTORY (#6 above) as well as recurse the subdirectories below the base directory (y/n)?

     # Run In Base Directory For: 
         UpdateOwnerAndPermissionsBase=y
         
     # Run In Base Directory For: 
         htaccess2indexBase=n
	
# 8. Do you want to stop the recursive feature and run ONLY in the base directory (y/n)?
   # Hint: to run a script on a foreign directory specify it as the BaseDirectory and set UpdateOwnerAndPermissionsBase=y and htaccess2indexBase=y and StopRecursive=y
     
	 StopRecursive=n

# 9. DEFINE A VERY SHORT WAV FILE TO PLAY IF ERRORS ARE FOUND
     # Leave it as a nonexistingfile to speed up processing
     # Example: errorsound=/home/media/beep.wav

     errorsound=/home/bill/nonexistingfile.wav
     





##################################################################
# Enter user variables needed to update ownership and permissions
# of files and directories.
##################################################################
#
# Script will automatically update ownership and permissions in ALL
# subdirectories because they are frequently wrong when new files are added
# to a website.

# RUN AS ROOT
# Run this script at the menu, as a sudoer, at the root user's command line, or as a root cron job ("bash <path>/Run-Htaccess2index-Recursively.bash").

#  PERMISSION REFERENCE, triplets to numeric:
# -------------------------------------------
#  Individual permissions: r--(read)=4    -w-(write)=2    --x(execute)=1
#  Permissions grouped into triplets: rwx=4+2+1=7  rw-=4+2=6     r-x=4+1=5     -wx=2+1=3

#  Triplets are put in order by owner,group, and others
#	rwxrwxrwx = 777
#	rwxrw-r-- = 764
#	rwxr-x--- = 750
#	rwx--x--- = 710
#--------------------------------------------


# 10. Specify the Owner and Group to assign to web page files.

        owner=bill
        group=www-data

# 11. Permissions to set for all files (exceptions below) - Use numeric format

        File_permissions=666

# 12. Permissions to set for all Directories (exceptions below) - Use numeric format

        Dir_permissions=775

# 13. If the "Sticky bit" is set on a folder, the folder contents can be deleted only by the owner who created them or the root user. 
         # Be careful using this!
     # Do you want to set the sticky bit on all directories? Enter y, r to remove, or blank for no cnange (recommended).

        stickybit=

# 14. If the guid is set, all new files and subdirectories created within the directories inherit the group ID of the directory, rather than the primary group ID of the user who created the file. 
         # Be careful using this!
     # Note that this applies only to newly-created files. Files that are moved or copied into the directory are NOT affected.
     # Do you want to set the guid on all directories? Enter y, r to remove, or blank for no cnange (recommended).

        setguid=

# You may specify exceptions to permissions set above:
# 15. Permissions to set for up to five files in ALL subdirectories (RECURSIVE).

        specialfile1=*.php
        specialfilepermissions1=640

        specialfile2=
        specialfilepermissions2=

        specialfile3=
        specialfilepermissions3=

        specialfile4=
        specialfilepermissions4=

        specialfile5=
        specialfilepermissions5=

# You may specify up to 8 additional scripts, or simple individual commands (NON-RECURSIVE).
# 16. Enter command, path, and filename of special requirements.
     # Examples:
     # a="sh /media/videos/script.sh"
     # a="chmod --preserve-root g+s /var/www/html"
     # b="chmod --preserve-root 755 /home/joe/filename"
     # c="cd /uploads"

	a=""
	b=""
	c=""
	d=""
	e=""
	f=""
	g=""
	h=""







#######################################################################
# Enter user variables needed to produce or update webpage index files.
#######################################################################
#
# This bash script reads all subdirectories, extracting
# the filenames (and the play-length of any A/V files therein).
# It also reads an apache2 style .htaccess file, or a similarly
# formatted file, containing descriptive info about the
# filename. It then produces html download links to the files
# and combines the Description data from .htaccess (or similar)
# with the user's headers and footers into files named
# "index.html" and "index2.html", the first sorted by filename
# and the second sorted by description.
#
# Styles are not used, just plain old html.
# (see the README.html file for details).
#
# "Run-Htaccess2index-Recursively.bash" will call "htaccess2index.bash."
#
# DO NOT RUN AS ROOT
# Run this script at the menu, the user's command line, or as a user's cron job ("bash <path>/Run-Htaccess2index-Recursively.bash").

# FILL IN THE REQUESTED DATA AFTER THE "<variablename>="
# IF THERE ARE ANY SPACES IN YOUR ENTRY YOU MUST ENCLOSE YOUR ENTRY IN QUOTES
#      No spaces around the equal signs.

# 17. FILE DESCRIPTIONS NAMED BELOW MAY BE LOCATED IN ANY OR EVERY DIRECTORY OR SUBDIRECTORY. 
          # If the file you define below does not exist in the directory being processed, the script will check successively higher directories until it reaches the base directory. 
              # Example: DescriptionFile=descrip.txt
                 # A spreadsheet is included to aid in entering and formatting the description files.

     DescriptionFile=descriptions.txt

# 18. DEFINE THE MAXIMUM NUMBER OF FILES TO LIST THAT HAVE NO DESCRIPTION.
# Example: NDmaxfiles=300

     NDmaxfiles=100

# 19. SIMPLE HTML PAGE HEADER INFORMATION. YOU ARE ALLOWED UP TO 11 LINES, EACH LINE WILL WRAP ON THE SCREEN. HTML IS OK. (BE SURE TO USE SINGLE QUOTES, AND NO SPACES AROUND THE = SIGN)

     header1='<!DOCTYPE html>'
     header2='<html>'
     header3='<head>'
     header4='<meta name="viewport" content="width=device-width, initial-scale=1">'
#    header 5 (<title>) is reserved as the name of the current directory
     header6='<meta http-equiv="content-type" content="text/html"; charset="UTF-8"/>'
     header7='<link rel="icon" href="/images/favicon.ico" sizes="16x16 32x32" type="/image/png"/>'
     header8=''
     header9=''
     header10='</head><body><a name="top"></a>'
#    header11 must follow '<body>' and is reserved as the name of the current directory
#    header 12 is reserved
     header13="<center><font size=-2>Updated $(date +%y-%m-%d/%H:%M)</font></center>"
     header14="<center><font size=-1>Use your browser's search function to find specific text.</font></center>"
#     header 15 is reserved
#     header 16 is reserved
     header17=''
#    HEADER LINES 12, 15, 16 ARE DYNAMIC AND NAVIGATION LINKS, USUALLY NO CHANGES ARE NEEDED. THEY CONTAIN MUCH MORE COMPLEX LINKS AND ARE FOUND IN THE "BUILD AN HTML FILE" SECTION OF "htaccess2index.bash"


# 20. PAGE FOOTER INFORMATION. (BE SURE TO USE QUOTES, AND NO SPACES AROUND THE = SIGN)

     footer1='<hr><center><b>Thanks for using the site. Requests <u>MAY</u> be honored.</b><p></p>'
     footer2='<a href="mailto: Webmaster@wrcraig.com">Click Here to email a request or suggestion.</a></center>'
     footer3=''
     footer4=''
     footer5="<br/></body>"
     footer6="</html>"

# 21. ENTER UP TO 10 FILE EXTENSIONS TO EXCLUDE FROM PROCESSING (Case insensitive, no leading dot please):
     # examples: ext1=html   or   ext2=bash

     ext1=jpg
     ext2=html
     ext3=log
     ext4=htm
     ext5=sh
     ext6=bak
     ext7=bash
     ext7=
     ext9=
     ext10=

# 22. ENTER UP TO 10 FILENAMES, OR PARTIAL FILENAMES, TO EXCLUDE FROM PROCESSING:
     #examples: file1=test.txt   or  file1=partialfilename
     
     file1=descriptions        
     file2=
     file3=
     file4=
     file5=
     file6=
     file7=
     file8=
     file9=
     file10=


############## END OF USER VARIABLES ##############


