#!/bin/bash

# menu.bash
clear
echo
echo -- This is the menu system for the htaccess2index system written in the bash scripting language.
echo
echo -- All the accompaning scripts should be saved together in a single directory.
echo -- Open a terminal and change to that directory. Then enter "bash menu.bash"
echo -- Open the README.html file to learn about the system.
echo 

scripts=${PWD}

if [ ! -f htaccess-config.bash ]
then
    echo The current directory is ${PWD}
	startingdir=${PWD}
    read -p "In what directory are the scripts located, - Ctl-c to quit: " scripts
    cd $scripts
fi  

if [ -f $scripts/htaccess-config.bash ]
then
echo Import functions and variables from the config and functions files
source $scripts"/htaccess-config.bash"
source $scripts"/functions.bash"
else
  echo "All scripts should be in the same directory."
fi

if [ ! -f htaccess-config.bash ] || [ ! -f ReplSpacesinSubdirs.Filenames.bash ] || [ ! -f Add-eqsign-ToDirectoryNames.bash ] || [ ! -f UpdateOwnerAndPermissions.bash ] || [ ! -f UpdateOwnerAndPermissionsRecursively.bash ] || [ ! -f htaccess2index.bash ] || [ ! -f Run-Htaccess2index-Recursively.bash ] || [ ! -f README.html ] || [ ! -f functions.bash ] || [ ! -f enterdescriptions.xls ]
then
    echo Some scripts were not found in ${scripts}
    echo Exiting...
    echo
    cd $startingdir
    exit
fi  

# Enforce not run as root
if [[ $EUID -eq 0 ]]; then
  echo
  echo
  echo
  echo
  echo '       You must NOT run this script as Root.'
  echo
  exit
fi

clear
echo
highlight "        MENU         "
echo
PS3="Select the operation, - Ctl-c to quit: "
select opt in Display_README.html Configure_system Replace_spaces_with_dots_in_all_dirs_and_files Add_equals_sign_to_Directory_Names Add_user_id_and_password Delete_user_id_and_password Enter_File_Descriptions Update_Owner_And_Permissions Create_html_Indexes; do

  case $opt in
     Display_README.html)
      echo
      echo Opening README.html with default web browser.
      xdg-open README.html && bash menu.bash
      ;;
     Configure_system)
      echo
      echo Opening htaccess-config.bash with default text editor.
      xdg-open htaccess-config.bash && bash menu.bash
      ;;
     Replace_spaces_with_dots_in_all_dirs_and_files)
      echo
	  bash ReplSpacesinSubdirs.Filenames.bash
	  echo
	  ;;
     Add_equals_sign_to_Directory_Names)
	  bash Add-eqsign-ToDirectoryNames.bash
	  echo
	  ;;
     Add_user_id_and_password)
      echo
	  enter_user
	  echo
	  ;;
     Delete_user_id_and_password)
      echo
	  delete_user
	  echo
	  ;;
     Enter_File_Descriptions)
	  echo
	  echo Opening enterdescriptions.xls with default spreadsheet application.
	 xdg-open enterdescriptions.xls && bash menu.bash
	  echo
          ;;
     Update_Owner_And_Permissions)
	  sudo bash UpdateOwnerAndPermissionsRecursively.bash
	  echo
	  ;;
    Create_html_Indexes)
          echo
          bash Run-Htaccess2index-Recursively.bash
          echo
          ;;
    *)
      echo
      echo "Invalid option $REPLY"
        echo
          ;;
  esac
done



